# CNFgen formula generator and tools

This repository provides the command

- `cnfgen` formula generator;

and the following python scripts, designed to operate from/to dimacs
CNFs:

- `cnfshuffle` random shuffler;

You  can get  a  brief help  on  how  to use  these  tools by  running
`<program_name> --help` from the command line.

Run `cnfgen --help` to get a list of the implemented formula families.
To get  more specific information  on one  class of formula  use the
command

    cnfgen <formula_type> --help

## Resources

- Webpage of the project at <http://massimolauria.net/cnfgen/>
- Technical documentation <https://cnfgen.readthedocs.io/en/latest/>
- Python Package at <https://pypi.org/project/CNFgen/>
- Github repository <https://github.com/MassimoLauria/cnfgen>
- Zenodo link (DOI) <https://zenodo.org/record/3548843>


Copyright 2012-2020  © Massimo
Lauria ([massimo.lauria@uniroma1.it](mailto:massimo.lauria@uniroma1.it))
